pub struct GcodeSerial { /* private fields */ }Implementations
Sourceimpl GcodeSerial
impl GcodeSerial
pub fn new(tx: Sender<Action>) -> Self
Sourcepub async fn start(&mut self, serial_connector: SerialConnector)
pub async fn start(&mut self, serial_connector: SerialConnector)
connect to printer and initialize lib
Sourcepub fn set_temps(&mut self, bed_temp: u16, extruder_temp: u16)
pub fn set_temps(&mut self, bed_temp: u16, extruder_temp: u16)
set target temperatures of bed and extruder
Sourcepub fn start_print(&mut self, file_path: String)
pub fn start_print(&mut self, file_path: String)
start a new print of given gcode file path won’t start file if event que size > 10
Sourcepub fn stop_print(&self)
pub fn stop_print(&self)
stop the active print and add the stop gcode to que